@@ -1,6 +1,7 @@
-# -*- coding: utf-8 -*-
-# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
 from .parser import CliParser
+
+__all__ = ("CliParser",)
