@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
@@ -41,6 +40,16 @@ _CONFIG = (
         "NOTUS_SCANNER_MQTT_BROKER_ADDRESS",
         DEFAULT_MQTT_BROKER_ADDRESS,
     ),
+    (
+        "mqtt-broker-username",
+        "NOTUS_SCANNER_MQTT_BROKER_USERNAME",
+        None,
+    ),
+    (
+        "mqtt-broker-password",
+        "NOTUS_SCANNER_MQTT_BROKER_PASSWORD",
+        None,
+    ),
     (
         "mqtt-broker-port",
         "NOTUS_SCANNER_MQTT_BROKER_PORT",
