@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
@@ -9,6 +8,7 @@ from functools import partial
 from typing import Callable, Type
 
 import paho.mqtt.client as mqtt
+from paho.mqtt import __version__ as paho_mqtt_version
 
 from ..errors import MessageParsingError
 from ..messages.message import Message
@@ -22,6 +22,10 @@ NOTUS_MQTT_CLIENT_ID = "notus-scanner"
 QOS_AT_LEAST_ONCE = 1
 
 
+def is_paho_mqtt_version_2() -> bool:
+    return paho_mqtt_version.startswith("2")
+
+
 class MQTTClient(mqtt.Client):
     def __init__(
         self,
@@ -32,7 +36,20 @@ class MQTTClient(mqtt.Client):
         self._mqtt_broker_address = mqtt_broker_address
         self._mqtt_broker_port = mqtt_broker_port
 
-        super().__init__(client_id=client_id, protocol=mqtt.MQTTv5)
+        mqtt_client_args = {
+            "client_id": client_id,
+            "protocol": mqtt.MQTTv5,
+        }
+
+        if is_paho_mqtt_version_2():
+            logger.debug("Using Paho MQTT version 2")
+            mqtt_client_args["callback_api_version"] = (
+                mqtt.CallbackAPIVersion.VERSION1
+            )
+        else:
+            logger.debug("Using Paho MQTT version 1")
+
+        super().__init__(**mqtt_client_args)
 
         self.enable_logger()
 
