@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
@@ -44,7 +43,7 @@ class Vulnerabilities:
         return len(self.vulnerabilities)
 
     def add(self, oid: str, vul: Vulnerability):
-        if not oid in self.vulnerabilities:
+        if oid not in self.vulnerabilities:
             self.vulnerabilities[oid] = vul
             return
 
